==> qcoro_0.11.0.orig.tar.gz: qcoro-0.11.0/docs/changelog.md <==
---
title: Changelog
---

<!--
SPDX-FileCopyrightText: 2022 Daniel Vrátil <dvratil@kde.org>

SPDX-License-Identifier: GFDL-1.3-or-later
-->

# Changelog

## 0.10.0 (2023-12-05)

* [Release announcement](news/2023/2023-12-05-qcoro-0.10.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.10.0)

## 0.9.0 (2023-04-27)

* [Release announcement](news/2023/2023-04-27-qcoro-0.9.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.9.0)

## 0.8.0 (2023-01-31)

* [Release announcement](news/2023/2023-01-31-qcoro-0.8.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.8.0)

## 0.7.0 (2022-11-20)

* [Release announcement](news/2022/2022-11-17-qcoro-0.7.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.7.0)

## 0.6.0 (2022-07-09)

* [Release announcement](news/2022/2022-07-09-qcoro-0.6.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.6.0)

## 0.5.1 (2022-04-27)

* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.5.1)

## 0.5.0 (2022-04-25)

* [Release announcement](news/2022/2022-04-25-qcoro-0.5.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.5.0)

## 0.4.0 (2022-01-06)

* [Release announcement](news/2022/2022-01-06-qcoro-0.4.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.4.0)

## 0.3.0 (2021-10-11)

* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.3.0)

## 0.2.0 (2021-09-08)

* [Release announcement](news/2021/2021-09-08-qcoro-0.2.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.2.0)

## 0.1.0 (2021-08-15)

* Initial release QCoro
* [Release announcement](news/2021/2021-08-16-qcoro-0.1.0-announcement.md)

==> qcoro_0.12.0.orig.tar.gz: qcoro-0.12.0/docs/changelog.md <==
---
title: Changelog
---

<!--
SPDX-FileCopyrightText: 2022 Daniel Vrátil <dvratil@kde.org>

SPDX-License-Identifier: GFDL-1.3-or-later
-->

# Changelog

## 0.11.0 (2024-10-04)

* [Release announcement](news/2024/2024-10-04-qcoro-0.11.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.11.0)

## 0.10.0 (2023-12-05)

* [Release announcement](news/2023/2023-12-05-qcoro-0.10.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.10.0)

## 0.9.0 (2023-04-27)

* [Release announcement](news/2023/2023-04-27-qcoro-0.9.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.9.0)

## 0.8.0 (2023-01-31)

* [Release announcement](news/2023/2023-01-31-qcoro-0.8.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.8.0)

## 0.7.0 (2022-11-20)

* [Release announcement](news/2022/2022-11-17-qcoro-0.7.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.7.0)

## 0.6.0 (2022-07-09)

* [Release announcement](news/2022/2022-07-09-qcoro-0.6.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.6.0)

## 0.5.1 (2022-04-27)

* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.5.1)

## 0.5.0 (2022-04-25)

* [Release announcement](news/2022/2022-04-25-qcoro-0.5.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.5.0)

## 0.4.0 (2022-01-06)

* [Release announcement](news/2022/2022-01-06-qcoro-0.4.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.4.0)

## 0.3.0 (2021-10-11)

* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.3.0)

## 0.2.0 (2021-09-08)

* [Release announcement](news/2021/2021-09-08-qcoro-0.2.0-announcement.md)
* [Github release changelog](https://github.com/danvratil/qcoro/releases/tag/v0.2.0)

## 0.1.0 (2021-08-15)

* Initial release QCoro
* [Release announcement](news/2021/2021-08-16-qcoro-0.1.0-announcement.md)
